import logging

SEPARATOR = '------'

logger = logging.getLogger("splitter")


def splitter(lines):
    """Return single logfile items from lines

    """
    logger.debug("Starting splitter...")
    content = []
    for line in lines:
        if line.startswith(SEPARATOR):
            if content:
                yield content
            content = []
        else:
            content.append(line)
    # Last line isn't closed with a separator
    if content:
        yield content


def extractor(entry):
    """Extract info from a single entry.

    We want to extract the year, month, day. And some meaningful
    error-related title. And the error level.

    """
    result = {}
    result['content'] = entry
    firstLine = entry[0]
    # The first line looks like:
    # 2006-06-28T11:25:54 WARNING Bla bla bla bla.
    result['year'] = firstLine[0:4]
    result['month'] = firstLine[5:7]
    result['day'] = firstLine[8:10]
    level = firstLine[20:]
    # Just the part before the first space:
    parts = level.split(' ')
    level = parts[0]
    title = ' '.join(parts[1:])
    result['level'] = level
    result['title'] = title
    result['error'] = None
    result['errortext'] = None

    lastLine = None
    if len(entry) > 1:
        lastLine = entry[-1].strip()
    if not lastLine:
        if len(entry) > 2:
            # In rare cases, there's a blank line at the end.
            lastLine = entry[-2]
    if level.startswith('ERROR') and lastLine:
        # Actuall error (like KeyError) is the first word on the last
        # line.
        parts = lastLine.split(':')
        firstWord = parts[0].strip()
        result['error'] = firstWord
        result['errortext'] = ':'.join(parts[1:])
    # Some weird zope2-ish stuff.
    firstLineErrors = ['uncatalogObject',
                       'ZServer',
                       'LDAPUserFolder',
                       'ZODB.Connection',
                       'Zope.UnIndex',
                       ]
    if level.startswith('ERROR') and not lastLine:
        for firstLineError in firstLineErrors:
            if firstLineError in firstLine:
                result['error'] = '%s_error' % firstLineError
                parts = firstLine.split(firstLineError)
                result['errortext'] = parts[1]
    return result
